/** =======================================================================
 *  Vincent Hardy
 *  License terms: see svg-wow.org
 *  CC0 http://creativecommons.org/publicdomain/zero/1.0/
 *  ======================================================================= */
var svgNS = "http://www.w3.org/2000/svg";

function init() {
    var srcPath = document.getElementById("svgPath");
    var dstPath = document.getElementById("wowPath");
    var srcPathLength = srcPath.getTotalLength();
    var dstPathLength = dstPath.getTotalLength();

    var markers = document.getElementById("markers");
    var n = 250;


    var srcGap = srcPathLength / n;
    var dstGap = dstPathLength / n;

    var minR = 2;
    var deltaR = 5;
    var dPos = 4;
    var dots = [];

    for (var i = 0; i < n; i++) {
        var dot = document.createElementNS(svgNS, "circle");
        dots.push(dot);
        var coords = srcPath.getPointAtLength(srcGap * i);
        var dstCoords = dstPath.getPointAtLength(dstGap * i);
        var dr = 1 - Math.sqrt(dx * dx + dy * dy);
        var thetaX = Math.random() * Math.PI * 2;
        var thetaY = Math.random() * Math.PI * 2;
        var dx = Math.cos(thetaX) * dPos;
        var dy = Math.cos(thetaY) * dPos;

        dot.setAttributes({
            r: minR + dr * deltaR,
            cx: coords.x + dx,
            cy: coords.y + dy,
            display: "none"
        });

        if (Math.random() > 0.5) {
            dot.growingFactor = 1;
        } else {
            dot.growingFactor = -1;
        }
        dot.radius = minR + dr * deltaR;
        dot.thetaX = thetaX;
        dot.thetaY = thetaY;
        dot.coords = coords;
        dot.srcCoords = coords;
        dot.dstCoords = dstCoords;
        
        markers.appendChild(dot);
    }

    randomShow = getRandomShow(dots);

    dotInterpolator = getDotInterpolator(dots, minR + 0.5 * deltaR, minR);
}

var showRunningId = undefined;

var runningId = undefined;
var dotInterpolator = undefined;

function getRandomShow (dotsArray) {
    var dots = [].concat(dotsArray);

    return function () {
        for (var i = 0; i < 1; i++) {
            if (dots.length === 0) {
                clearInterval(showRunningId);
                break;
            } else {
                var dotIndex = Math.floor(Math.random() * dots.length);
                dots[dotIndex].setAttribute("display", "inline");
                dots.splice(dotIndex, 1);
            }
        }
    }
}

var movingToDst = false;
var srcToDstRatio = 0;


function getDotInterpolator (dots, maxR, minR) {
    var nDots = dots.length;

    return function () {
        for (var i = 0; i < nDots; i++) {
            var growNow = (Math.random(1) > 0.5 ? true : false);
            var p = srcToDstRatio;
            var np = 1 - p;
            var dPos = 2;

            var dot = dots[i];
            if (growNow === true) {                
                var r = dot.radius + dot.growingFactor * 0.25;
                if (r > maxR) {
                    dot.growingFactor = -1;
                } else if (r < minR) {
                    r = minR;
                    dot.growingFactor = 1;
                }
                dot.setAttribute("r", r);
                dot.radius = r;
            } else {
                dot.thetaX = (dot.thetaX + Math.PI / 20) % (2 * Math.PI);
                dot.thetaY = (dot.thetaY + Math.PI / 20) % (2 * Math.PI);
                dot.setAttribute("cx", np * dot.coords.x + p * dot.dstCoords.x + Math.cos(dot.thetaX) * dPos);
                dot.setAttribute("cy", np * dot.coords.y + p * dot.dstCoords.y + Math.cos(dot.thetaY) * dPos);
            }
        }

        if (movingToDst === true) {
            srcToDstRatio += 0.08;
            if (srcToDstRatio >= 1) {
                srcToDstRatio = 1;
                movingToDst = false;
            }
        }
    };
}

function stopOrGo () {
    if (showRunningId === undefined) {
        showRunningId = setInterval(randomShow, 40);
    }
    
    if (runningId !== undefined) {
        clearInterval(runningId);
        runningId = undefined;
        document.play.setAttribute("display", "inline");
        document.pause.setAttribute("display", "none");
    } else {
        runningId = setInterval(dotInterpolator, 40);
        document.play.setAttribute("display", "none");
        document.pause.setAttribute("display", "inline");
    }
}